; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
name = "SynnSuperF" ;Summon Dragon(Synn)
command = ~D, DF, F, D, DF, F, z+c
time = 30

[Command]
name = "SynnSuperB" ;Summon Dragon(Synn), other side
command = ~D, DB, B, D, DB, B, z+c
time = 30

[Command]
name = "DragBSuper"
command = ~D, DF, F, D, DF, F, a
time = 30

[Command]
name = "DragBSuper2"
command = ~D, DF, F, D, DF, F, b
time = 30

[Command]
name = "StatueSuper"
command = ~D, DB, B, D, DB, B, a
time = 30

[Command]
name = "StatueSuper2"
command = ~D, DB, B, D, DB, B, b
time = 30

[Command]
name = "AuraSuper"
command = ~D, DF, F, D, DF, F, x
time = 30

[Command]
name = "AuraSuper2"
command = ~D, DF, F, D, DF, F, y
time = 30

[Command]
name = "StompSuper"
command = ~D, DB, B, D, DB, B, x
time = 30

[Command]
name = "StompSuper2"
command = ~D, DB, B, D, DB, B, y
time = 30

[Command]
name = "TripleKFPalm"
command = ~D, DF, F, D, DF, F, x
time = 20

[Command]
name = "TripleKFPalm"   ;Same name as above
command = ~D, DF, F, D, DF, F, y
time = 20

[Command]
name = "SmashKFUpper"
command = ~D, DB, B, D, DB, B, x;~F, D, DF, F, D, DF, x
time = 20

[Command]
name = "SmashKFUpper"   ;Same name as above
command = ~D, DB, B, D, DB, B, y;~F, D, DF, F, D, DF, y
time = 20

[Command]
name = "SuperThief"
command = ~D, DB, B, x+y
time = 20

[Command]
name = "SuperThief"
command = ~D, DB, B, a+b
time = 20

;[Command] ;Dirty version
;name = "SuperThief"
;command = s
;time = 20

;-| EX Motions |------------------------------------------------------
[Command]
name = "FistGaulEX"
command = ~D, DF, F, y+x
time = 20

[Command]
name = "DragBEX"
command = ~D, DF, F, a+b
time = 20

;-| Special Motions |------------------------------------------------------
[Command]
name = "HighJump"
command = ~D, U
time = 20

name = "HighJump"
command = ~D, UF
time = 20

name = "HighJump"
command = ~D, UB
time = 20

[Command]
name = "ShortAxeUpper"
command = ~F, D, DF, F, x
time = 25

[Command]
name = "HighAxeUpper"
command = ~F, D, DF, F, y
time = 25

[Command]
name = "FistGaul"
command = ~D, DF, F, x
time = 20

[Command]
name = "FistGaul"
command = ~D, DF, F, y
time = 20

[Command]
name = "DragBShort"
command = ~D, DF, F, a
time = 20

[Command]
name = "DragBLong"
command = ~D, DF, F, b
time = 20

[Command]
name = "ShieldCharge"
command = ~F, DF, D, DB, B, x
time = 30

;EASIER SHIELD CHARGE TEST
;[Command]
;name = "ShieldCharge"
;command = ~D, DB, B, x
;time = 20

[Command]
name = "ShieldCharge"
command = ~F, DF, D, DB, B, y
time = 30

[Command]
name = "Grab1"
command = x+y
time = 10

[Command]
name = "Grab2"
command = a+b
time = 10

[Command]
name = "upper_x"
command = ~F, D, DF, x

[Command]
name = "upper_y"
command = ~F, D, DF, y

[Command]
name = "upper_xy"
command = ~F, D, DF, x+y

[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCF_xy"
command = ~D, DF, F, x+y

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_y"
command = ~D, DB, B, y

[Command]
name = "QCB_xy"
command = ~D, DB, B, x+y

[Command]
name = "FF_ab"
command = F, F, a+b

[Command]
name = "FF_a"
command = F, F, a

[Command]
name = "FF_b"
command = F, F, b

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 16

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 16

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

[Command]
name = "hold_z";Required (do not remove)
command = /$z
time = 1

[Command]
name = "Guard"  ;Required (do not remove)
command = /c
time = 1

[Command]
name = "SuperGuard"  ;Required (do not remove)
command = /z
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


;-| CPU ONLY (DUMMY MOVES ONLY THE COMPUTER CAN DO THAT ACTIVATE HIS AI |-----------------------
[Command]
name = "CPU1"
command = D, D, U, U, D, U
time = 1

[Command]
name = "CPU2"
command = D, U, U, D, D, U
time = 1

[Command]
name = "CPU3"
command = D, D, D, U, U, U
time = 1

[Command]
name = "CPU4"
command = U, D, D, U, U, U
time = 1

[Command]
name = "CPU5"
command = D, D, U, U, D, D
time = 1

[Command]
name = "CPU6"
command = U, D, D, D, D, U
time = 1

[Command]
name = "CPU7"
command = U, U, U, U, U, D
time = 1

[Command]
name = "CPU8"
command = U, U, U, U, D, U
time = 1

[Command]
name = "CPU9"
command = U, U, U, D, U, U
time = 1

[Command]
name = "CPU10"
command = U, U, D, U, U, U
time = 1

[Command]
name = "CPU11"
command = U, D, U, U, U, U
time = 1

[Command]
name = "CPU12"
command = D, U, D, U, D, U
time = 1

[Command]
name = "CPU13"
command = U, U, D, U, U, U, U
time = 1

[Command]
name = "CPU14"
command = U, D, D, U, U, U, U
time = 1

[Command]
name = "CPU15"
command = D, U, D, U, U, U, D
time = 1

[Command]
name = "CPU16"
command = D, D, D, U, U, U, U
time = 1

[Command]
name = "CPU17"
command = U, U, D, U, U, D, D
time = 1

[Command]
name = "CPU18"
command = D, D, D, U, D, D, D
time = 1

[Command]
name = "CPU19"
command = U, D, D, U, D, U, D
time = 1

[Command]
name = "CPU20"
command = D, D, D, U, U, U, D
time = 1

[Command]
name = "CPU21"
command = U, D, U, D, U, U, U
time = 1

[Command]
name = "CPU22"
command = U, U, U, U, U, U, U
time = 1

[Command]
name = "CPU23"
command = D, D, D, D, D, D, D
time = 1

[Command]
name = "CPU24"
command = D, D, D, D, D, D, U
time = 1

[Command]
name = "CPU25"
command = D, D, D, D, D, U, D
time = 1

[Command]
name = "CPU26"
command = D, D, U, U, D, U
time = 1

[Command]
name = "CPU27"
command = D, U, U, D, D, U
time = 1

[Command]
name = "CPU28"
command = D, D, D, U, U, U
time = 1

[Command]
name = "CPU29"
command = U, D, D, U, U, U
time = 1

[Command]
name = "CPU30"
command = D, D, U, U, D, D
time = 1

[Command]
name = "CPU31"
command = U, D, D, D, D, U
time = 1

[Command]
name = "CPU32"
command = U, U, U, U, U, D
time = 1

[Command]
name = "CPU33"
command = U, U, U, U, D, U
time = 1

[Command]
name = "CPU34"
command = U, U, U, D, U, U
time = 1

[Command]
name = "CPU35"
command = U, U, D, U, U, U
time = 1

[Command]
name = "CPU36"
command = U, D, U, U, U, U
time = 1

[Command]
name = "CPU37"
command = D, U, D, U, D, U
time = 1

[Command]
name = "CPU38"
command = U, U, D, U, U, U, U
time = 1

[Command]
name = "CPU39"
command = U, D, D, U, U, U, U
time = 1

[Command]
name = "CPU40"
command = D, U, D, U, U, U, D
time = 1

[Command]
name = "CPU41"
command = D, D, D, U, U, U, U
time = 1

[Command]
name = "CPU42"
command = U, U, D, U, U, D, D
time = 1

[Command]
name = "CPU43"
command = D, D, D, U, D, D, D
time = 1

[Command]
name = "CPU44"
command = U, D, D, U, D, U, D
time = 1

[Command]
name = "CPU45"
command = D, D, D, U, U, U, D
time = 1

[Command]
name = "CPU46"
command = U, D, U, D, U, U, U
time = 1

[Command]
name = "CPU47"
command = U, U, U, U, U, U, U
time = 1

[Command]
name = "CPU48"
command = D, D, D, D, D, D, D
time = 1

[Command]
name = "CPU49"
command = D, D, D, D, D, D, U
time = 1

[Command]
name = "CPU50"
command = D, D, D, D, D, U, D
time = 1

[Statedef -1]

[State -1, AITurnOn]
type = VarSet
triggerall = var(21) != 1
triggerall = var(20) != 999
trigger1  = command = "CPU1"
trigger2  = command = "CPU2"
trigger3  = command = "CPU3"
trigger4  = command = "CPU4"
trigger5  = command = "CPU5"
trigger6  = command = "CPU6"
trigger7  = command = "CPU7"
trigger8  = command = "CPU8"
trigger9  = command = "CPU9"
trigger10 = command = "CPU10"
trigger11 = command = "CPU11"
trigger12 = command = "CPU12"
trigger13 = command = "CPU13"
trigger14 = command = "CPU14"
trigger15 = command = "CPU15"
trigger16 = command = "CPU16"
trigger17 = command = "CPU17"
trigger18 = command = "CPU18"
trigger19 = command = "CPU19"
trigger20 = command = "CPU20"
trigger21 = command = "CPU21"
trigger22 = command = "CPU22"
trigger23 = command = "CPU23"
trigger24 = command = "CPU24"
trigger25 = command = "CPU25"
trigger26 = Alive && !IsHelper
trigger26 = IsHomeTeam
trigger26 = TeamSide = 2 || MatchNo > 1
trigger27  = command = "CPU26"
trigger28  = command = "CPU27"
trigger29  = command = "CPU28"
trigger30  = command = "CPU29"
trigger31  = command = "CPU30"
trigger32  = command = "CPU31"
trigger33  = command = "CPU32"
trigger34  = command = "CPU33"
trigger35  = command = "CPU34"
trigger36 = command = "CPU35"
trigger37 = command = "CPU36"
trigger38 = command = "CPU37"
trigger39 = command = "CPU38"
trigger40 = command = "CPU39"
trigger41 = command = "CPU40"
trigger42 = command = "CPU41"
trigger43 = command = "CPU42"
trigger44 = command = "CPU43"
trigger45 = command = "CPU44"
trigger46 = command = "CPU45"
trigger47 = command = "CPU46"
trigger48 = command = "CPU47"
trigger49 = command = "CPU48"
trigger50 = command = "CPU49"
trigger51 = command = "CPU50"
v = 21
value = 1

;---------------------------------------------------------------------------
;Wake-Up Turning
[State -1, GuardWakeTurn]
type = Turn
triggerall = Anim = 5120
trigger1 = p2dist X < -18

;===========================================================================
;Sneak Evade (From Getup Anim)
[State -1]
type = ChangeState
value = 10010
triggerall = Anim = 5120
;triggerall = P2BodyDist X < 96
trigger1 = Command = "FF"
trigger2 = var(21) = 1
trigger2 = var(20) = [25,70]
trigger2 = P2BodyDist X < 96

;===========================================================================
;SUPER MOVES
;===========================================================================
;---------------------------------------------------------------------------
;---------------------------------------------------------------------------
;Super Thief
[State -1, Super Devour]
type = ChangeState
value = 2660
triggerall = var(21) != 1
triggerall = command = "SuperThief"
triggerall = power >= 1000
triggerall = var(43) > 0
;trigger1 = statetype != A
trigger1 = ctrl

;Ulitmate Dragon Summon Lvl 3 Foward
[State -1, SynnSuper]
type = ChangeState
value = 2100
triggerall = var(21) != 1
triggerall = command = "SynnSuperF"
triggerall = power >= 3000
trigger1 = statetype != A
trigger1 = ctrl

;Ulitmate Dragon Summon Lvl 3 Backwards
[State -1, SynnSuper]
type = ChangeState
value = 2103
triggerall = var(21) != 1
triggerall = command = "SynnSuperB"
triggerall = power >= 3000
trigger1 = statetype != A
trigger1 = ctrl

;Super Dragon Breath (Thunder) Lvl 1
[State -1, DragBSuper]
type = ChangeState
value = 1017
triggerall = var(21) != 1
triggerall = command = "DragBSuper"
triggerall = power >= 1000
trigger1 = statetype != A
trigger1 = ctrl
;trigger2 = stateno = 200 && time > 10
;trigger3 = stateno = 400 && movecontact = 1

;Super Dragon Breath (Thunder) Lvl 2
[State -1, DragBSuper2]
type = ChangeState
value = 1019
triggerall = var(21) != 1
triggerall = command = "DragBSuper2"
triggerall = power >= 2000
trigger1 = statetype != A
trigger1 = ctrl
;trigger2 = stateno = 200 && time > 10
;trigger3 = stateno = 400 && movecontact = 1

;Super Dragon Breath (Thunder) Lvl 1B
[State -1, DragBSuper]
type = ChangeState
value = 1017
triggerall = var(21) != 1
triggerall = command = "DragBSuper2"
triggerall = power >= 1000
triggerall = power < 2000
trigger1 = statetype != A
trigger1 = ctrl
;trigger2 = stateno = 200 && time > 10
;trigger3 = stateno = 400 && movecontact = 1

;Super Death Aura Lvl 1
[State -1, AuraSuper]
type = ChangeState
value = 2010
triggerall = var(21) != 1
triggerall = command = "AuraSuper"
triggerall = power >= 1000
trigger1 = statetype != A
trigger1 = ctrl
;trigger2 = stateno = 200 && movecontact = 1
trigger2 = stateno = [200,499]
trigger2 = movecontact = 1
trigger2 = Pos Y = 0
;trigger3 = stateno = 400 && movecontact = 1

;Super Death Aura Lvl 2
[State -1, AuraSuper]
type = ChangeState
value = 2012
triggerall = var(21) != 1
triggerall = command = "AuraSuper2"
triggerall = power >= 2000
trigger1 = statetype != A
trigger1 = ctrl
;trigger2 = stateno = 200 && movecontact = 1
trigger2 = stateno = [200,499]
trigger2 = movecontact = 1
trigger2 = Pos Y = 0
;trigger3 = stateno = 400 && movecontact = 1

;Super Death Aura Lvl 1B
[State -1, AuraSuper]
type = ChangeState
value = 2010
triggerall = var(21) != 1
triggerall = command = "AuraSuper2"
triggerall = power >= 1000
triggerall = power < 2000
trigger1 = statetype != A
trigger1 = ctrl
;trigger2 = stateno = 200 && movecontact = 1
trigger2 = stateno = [200,499]
trigger2 = movecontact = 1
trigger2 = Pos Y = 0
;trigger3 = stateno = 400 && movecontact = 1

; Super Dash-Smash-N-Stomp Lvl 1
[State -1, StompSuper]
type = ChangeState
value = 2020
triggerall = var(21) != 1
triggerall = command = "StompSuper"
triggerall = power >= 1000
trigger1 = statetype != A
trigger1 = ctrl
;trigger2 = stateno = 200 && time > 10
;trigger3 = stateno = 400 && movecontact = 1

; Super Dash-Smash-N-Stomp Lvl 2
[State -1, StompSuper2]
type = ChangeState
value = 2023
triggerall = var(21) != 1
triggerall = command = "StompSuper2"
triggerall = power >= 2000
trigger1 = statetype != A
trigger1 = ctrl
;trigger2 = stateno = 200 && time > 10
;trigger3 = stateno = 400 && movecontact = 1

; Super Dash-Smash-N-Stomp Lvl 1B
[State -1, StompSuper]
type = ChangeState
value = 2020
triggerall = var(21) != 1
triggerall = command = "StompSuper2"
triggerall = power >= 1000
triggerall = power < 2000
trigger1 = statetype != A
trigger1 = ctrl
;trigger2 = stateno = 200 && time > 10
;trigger3 = stateno = 400 && movecontact = 1

;Ego's Avalanche Lvl 1
[State -1, StatueSuper]
type = ChangeState
value = 2000
triggerall = var(21) != 1
triggerall = command = "StatueSuper"
triggerall = power >= 1000
trigger1 = statetype != A
trigger1 = ctrl
;trigger2 = stateno = 200 && time > 10
;trigger3 = stateno = 400 && movecontact = 1

;Ego's Avalanche Lvl 2
[State -1, StatueSuper]
type = ChangeState
value = 2003
triggerall = var(21) != 1
triggerall = command = "StatueSuper2"
triggerall = power >= 2000
trigger1 = statetype != A
trigger1 = ctrl
;trigger2 = stateno = 200 && time > 10
;trigger3 = stateno = 400 && movecontact = 1

;Ego's Avalanche Lvl 1B
[State -1, StatueSuper]
type = ChangeState
value = 2000
triggerall = var(21) != 1
triggerall = command = "StatueSuper2"
triggerall = power >= 1000
triggerall = power < 2000
trigger1 = statetype != A
trigger1 = ctrl
;trigger2 = stateno = 200 && time > 10
;trigger3 = stateno = 400 && movecontact = 1

;===========================================================================
;GUARDS, JUMPS & RUNS
;---------------------------------------------------------------------------
;Guard
[State -1, GuardStand]
type = ChangeState
value = 130
triggerall = command = "Guard"
triggerall = ctrl
triggerall = var(20) != 999
;triggerall = stateno != 130
;triggerall = stateno != 131
trigger1 = var(21) != 1
trigger1 = statetype = S

[State -1, GuardCrouch]
type = ChangeState
value = 131
triggerall = command = "Guard"
triggerall = ctrl
triggerall = var(20) != 999
;triggerall = stateno != 130
;triggerall = stateno != 131
trigger1 = var(21) != 1
trigger1 = statetype = C

[State -1, GuardAir]
type = ChangeState
value = 132
triggerall = command = "Guard"
triggerall = ctrl
triggerall = var(20) != 999
;triggerall = stateno != 130
;triggerall = stateno != 131
trigger1 = var(21) != 1
trigger1 = statetype = A

;Guard
[State -1, SuperGuardStand]
type = ChangeState
value = 130
triggerall = command = "SuperGuard"
triggerall = ctrl
triggerall = var(20) != 999
;triggerall = stateno != 130
;triggerall = stateno != 131
trigger1 = var(21) != 1
trigger1 = statetype = S

[State -1, SuperGuardCrouch]
type = ChangeState
value = 131
triggerall = command = "SuperGuard"
triggerall = ctrl
triggerall = var(20) != 999
;triggerall = stateno != 130
;triggerall = stateno != 131
trigger1 = var(21) != 1
trigger1 = statetype = C

[State -1, SuperGuardAir]
type = ChangeState
value = 132
triggerall = command = "SuperGuard"
triggerall = ctrl
triggerall = var(20) != 999
;triggerall = stateno != 130
;triggerall = stateno != 131
trigger1 = var(21) != 1
trigger1 = statetype = A

;---------------------------------------------------------------------------
;Wake-Up Crouch
[State -1, WakeCrouch]
type = ChangeState
value = 11
triggerall = Anim = 5120
;triggerall = var(21) != 1
trigger1 = command = "holddown"
trigger2 = var(21) = 1
trigger2 = var(20) = [45,65]
ctrl = 1

;High Jump
[State -1, High Jump]
type = ChangeState
value = 39
triggerall = var(21) != 1
trigger1 = command = "HighJump"
trigger1 = Pos Y > -20 ;statetype != A
trigger1 = ctrl

;Chained High Jump
[State -1, High Jump]
type = ChangeState
value = 37
triggerall = command = "holdup"
triggerall = var(21) != 1
trigger1 = stateno = 440 && movecontact
trigger2 = stateno = 610 && movecontact
trigger3 = stateno = 1500 && movecontact
trigger4 = stateno = 1501 && movecontact
trigger5 = stateno = 1024 && enemy(0),Vel Y < -10

;Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
;triggerall = var(21) != 1
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
[State -1, Run Back]
type = ChangeState
value = 105
;triggerall = var(21) != 1
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;===========================================================================
;EX SPECIAL MOVES
;===========================================================================
;---------------------------------------------------------------------------
;Fist of Gaul EX
[State -1, Fist of Gaul EX]
type = ChangeState
value = 1024
triggerall = var(21) != 1
triggerall = command = "FistGaulEX"
triggerall = power >= 250
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 && time > 10
trigger3 = stateno = 205 && hitcount >= 2
trigger3 = stateno = 205 && movecontact = 1
trigger3 = time >= 7
trigger4 = stateno = 240 && movecontact = 1
trigger5 = stateno = 400 && movecontact = 1
trigger6 = stateno = 410 && hitcount >= 2
trigger6 = stateno = 410 && movecontact = 1
trigger6 = time >= 7
trigger7 = stateno = 440 && movecontact = 1

;---------------------------------------------------------------------------
;EX Dragon Breath (Huge)
[State -1, DragBEX]
type = ChangeState
value = 1015
triggerall = var(21) != 1
triggerall = command = "DragBEX"
triggerall = power >= 250
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 && time > 10
trigger3 = stateno = 400 && movecontact = 1
trigger4 = stateno = 440 && movecontact = 1
trigger5 = stateno = 205 && hitcount >= 2
trigger5 = stateno = 205 && movecontact = 1
trigger5 = time >= 7
trigger6 = stateno = 410 && hitcount >= 2
trigger6 = stateno = 410 && movecontact = 1
trigger6 = time >= 7


;===========================================================================
;SPECIAL MOVES
;===========================================================================
;---------------------------------------------------------------------------
;High Axe Uppercut
[State -1, ShortAxeUpper]
type = ChangeState
value = 1510
triggerall = var(21) != 1
triggerall = command = "HighAxeUpper"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 && time > 10
trigger3 = stateno = 400 && movecontact = 1

;---------------------------------------------------------------------------
;Short Axe Uppercut
[State -1, ShortAxeUpper]
type = ChangeState
value = 1500
triggerall = var(21) != 1
triggerall = command = "ShortAxeUpper"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 && time > 10
trigger3 = stateno = 400 && movecontact = 1

;;---------------------------------------------------------------------------
;;Short Axe Uppercut (Wake-Up)
;[State -1, ShortAxeUpperWake]
;type = ChangeState
;value = 1500
;triggerall = var(21) != 1
;triggerall = anim = 5120
;trigger1 = command = "x"
;trigger2 = command = "y"

;---------------------------------------------------------------------------
;Shield Charge
[State -1, Shield Charge]
type = ChangeState
value = 1030
triggerall = var(21) != 1
triggerall = command = "ShieldCharge"
;trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 240 && movecontact = 1
;trigger2 = stateno = 200 && time > 10
;trigger3 = stateno = 400 && movecontact = 1

;---------------------------------------------------------------------------
;Fist of Gaul
[State -1, Fist of Gaul]
type = ChangeState
value = 1020
triggerall = var(21) != 1
triggerall = command = "FistGaul"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 && time > 10
trigger3 = stateno = 205 && hitcount >= 2
trigger3 = stateno = 205 && movecontact = 1
trigger3 = time >= 7
trigger4 = stateno = 240 && movecontact = 1
trigger5 = stateno = 400 && movecontact = 1
trigger6 = stateno = 410 && hitcount >= 2
trigger6 = stateno = 410 && movecontact = 1
trigger6 = time >= 7
trigger7 = stateno = 440 && movecontact = 1

;---------------------------------------------------------------------------
;Short Dragon Breath
[State -1, DragBShort]
type = ChangeState
value = 1010
triggerall = var(21) != 1
triggerall = command = "DragBShort"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 && time > 10
trigger3 = stateno = 400 && movecontact = 1
trigger4 = stateno = 440 && movecontact = 1
trigger5 = stateno = 205 && hitcount >= 2
trigger5 = stateno = 205 && movecontact = 1
trigger5 = time >= 7
trigger6 = stateno = 410 && hitcount >= 2
trigger6 = stateno = 410 && movecontact = 1
trigger6 = time >= 7

;---------------------------------------------------------------------------
;Long Dragon Breath
[State -1, DragBLong]
type = ChangeState
value = 1013
triggerall = var(21) != 1
triggerall = command = "DragBLong"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 && time > 10
trigger3 = stateno = 400 && movecontact = 1
trigger4 = stateno = 440 && movecontact = 1
trigger5 = stateno = 205 && hitcount >= 2
trigger5 = stateno = 205 && movecontact = 1
trigger5 = time >= 7
trigger6 = stateno = 410 && hitcount >= 2
trigger6 = stateno = 410 && movecontact = 1
trigger6 = time >= 7

;---------------------------------------------------------------------------
;Body Slam Throw (Foward)
[State -1, Body Slam Throw Foward]
type = ChangeState
value = 800
triggerall = var(21) != 1
triggerall = command = "Grab1"
triggerall = command = "holdfwd"
trigger1 = statetype != A
trigger1 = ctrl

;Body Slam Throw (Backward)
[State -1, Body Slam Throw Backward]
type = ChangeState
value = 801
triggerall = var(21) != 1
triggerall = command = "Grab1"
triggerall = command = "holdback"
trigger1 = statetype != A
trigger1 = ctrl
;trigger1 = (p2statetype = S) || (p2statetype = C)
;trigger1 = p2movetype != H
;trigger1 = p2bodydist X < 3
;trigger1 = p2movetype != H
;trigger2 = p2bodydist X < 5

;---------------------------------------------------------------------------
;Genesis Thunder Throw (P2 Fall Away)
[State -1, Genesis Throw1]
type = ChangeState
value = 820
triggerall = var(21) != 1
triggerall = command = "Grab2"
triggerall = statetype != A
trigger1 = command = "holdfwd"
trigger1 = ctrl

;---------------------------------------------------------------------------
;Genesis Thunder Throw (P2 Fall Forward)
[State -1, Genesis Throw2]
type = ChangeState
value = 824
triggerall = var(21) != 1
triggerall = command = "Grab2"
triggerall = statetype != A
trigger1 = command = "holdback"
trigger1 = ctrl

;===========================================================================
;---------------------------------------------------------------------------
;Alternate Stand Light Weapon (2-hitter)
[State -1, Stand Light Weapon]
type = ChangeState
value = 205
triggerall = var(21) != 1
triggerall = command = "x"
triggerall = command = "holdfwd"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200 && time > 6
trigger3 = stateno = 400 && movecontact = 1

;---------------------------------------------------------------------------
;Stand Light Weapon
[State -1, Stand Light Weapon]
type = ChangeState
value = 200
triggerall = var(21) != 1
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200 && time > 10
trigger3 = stateno = 400 && movecontact = 1

;---------------------------------------------------------------------------
;Stand Strong Weapon
[State -1, Stand Strong Weapon]
type = ChangeState
value = 220
triggerall = var(21) != 1
triggerall = command = "y"
triggerall = command = "holdfwd"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 105
trigger2 = Pos Y > -20
trigger3 = stateno = 200 && time > 3
trigger4 = stateno = 240 && movecontact = 1
trigger5 = stateno = 400 && movecontact = 1
trigger6 = stateno = 410 && hitcount >= 2 ;&& movecontact = 1 && time > 8
trigger6 = stateno = 410 && movecontact = 1
trigger6 = time >= 7
trigger7 = stateno = 440 && movecontact = 1
trigger8 = stateno = 230 && movecontact = 1
trigger9 = stateno = 430 && movecontact = 1
trigger10 = stateno = 210 && movecontact = 1
trigger11 = stateno = 205 && hitcount >= 2
trigger11 = stateno = 205 && movecontact = 1
trigger11 = time >= 7
;[State -1, Alt Stand Strong Weapon] ;For special ducking chains
;type = ChangeState
;value = 220
;triggerall = command = "y"
;triggerall = command = "holdfwd"
;triggerall = command = "holddown"
;trigger2 = stateno = 440 && movecontact = 1

;---------------------------------------------------------------------------
;Stand Medium Weapon
[State -1, Stand Medium Weapon]
type = ChangeState
value = 210
triggerall = var(21) != 1
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200 && time > 3
trigger3 = stateno = 240 && movecontact = 1
trigger4 = stateno = 400 && movecontact = 1
trigger5 = stateno = 410 && hitcount >= 2 ;&& movecontact = 1 && time > 8
trigger6 = stateno = 410 && movecontact = 1
trigger6 = time >= 7
trigger7 = stateno = 440 && movecontact = 1
trigger8 = stateno = 205 && hitcount >= 2
trigger8 = stateno = 205 && movecontact = 1
trigger8 = time >= 7
[State -1, Alt Stand Strong Weapon] ;For special ducking chains
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = stateno = 440 && movecontact = 1

;---------------------------------------------------------------------------
;Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = var(21) != 1
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200 && time > 3
trigger3 = stateno = 210 && movecontact = 1
trigger4 = stateno = 240 && movecontact = 1
trigger5 = stateno = 400 && movecontact = 1
trigger6 = stateno = 410 && hitcount >= 2 ;&& movecontact = 1 && time > 8
trigger7 = stateno = 410 && movecontact = 1
trigger7 = time >= 7
trigger8 = stateno = 205 && hitcount >= 2
trigger8 = stateno = 205 && movecontact = 1
trigger8 = time >= 7

;---------------------------------------------------------------------------
;Standing Strong Kick
[State -1, Standing Strong Kick]
type = ChangeState
value = 250
triggerall = var(21) != 1
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = command = "holdfwd"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 105
trigger2 = Pos Y > -20
trigger3 = stateno = 200 && time > 3
trigger4 = stateno = 400 && movecontact = 1
trigger5 = stateno = 410 && hitcount >= 2 ;&& movecontact = 1 && time > 8
trigger6 = stateno = 410 && movecontact = 1
trigger6 = time >= 7
trigger7 = stateno = 440 && movecontact = 1
trigger8 = stateno = 210 && movecontact = 1
trigger9 = stateno = 240 && movecontact = 1
trigger10 = stateno = 230 && movecontact = 1
trigger11 = stateno = 430 && movecontact = 1
trigger12 = stateno = 205 && hitcount >= 2
trigger12 = stateno = 205 && movecontact = 1
trigger12 = time >= 7
;Alt Standing Strong Kick
;[State -1, Standing Strong Kick]
;type = ChangeState
;value = 250
;triggerall = command = "b"
;trigger1 = stateno = 105
;trigger1 = Pos Y > -20

;---------------------------------------------------------------------------
;Standing Meduim Kick
[State -1, Standing Meduim Kick]
type = ChangeState
value = 240
triggerall = var(21) != 1
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200 && time > 3
trigger3 = stateno = 400 && movecontact = 1
trigger4 = stateno = 410 && hitcount >= 2 ;&& movecontact = 1 && time > 8
trigger5 = stateno = 410 && movecontact = 1
trigger5 = time >= 7
trigger6 = stateno = 440 && movecontact = 1
trigger7 = stateno = 205 && hitcount >= 2
trigger7 = stateno = 205 && movecontact = 1
trigger7 = time >= 7

;---------------------------------------------------------------------------
;Taunt
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Meduim Weapon
[State -1, Crouching Meduim Weapon]
type = ChangeState
value = 410
triggerall = var(21) != 1
triggerall = command = "x"
triggerall = command = "holdfwd"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 200 && time > 3
trigger3 = stateno = 400 && movecontact = 1

;---------------------------------------------------------------------------
;Crouching Light Weapon
[State -1, Crouching Light Weapon]
type = ChangeState
value = 400
triggerall = var(21) != 1
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 200 && time > 3

;---------------------------------------------------------------------------
;Crouching Strong Weapon
[State -1, Crouching Strong Weapon]
type = ChangeState
value = 420
triggerall = var(21) != 1
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 200 && time > 3
trigger3 = stateno = 400 && movecontact = 1
trigger4 = stateno = 240 && movecontact = 1
trigger5 = stateno = 410 && hitcount >= 2
;trigger6 = stateno = 410 && movecontact = 1
;trigger6 = time >= 7

;---------------------------------------------------------------------------
;Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = var(21) != 1
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 400 && movecontact = 1
trigger3 = stateno = 410 && hitcount >= 2 ;&& movecontact = 1 && time > 8
trigger4 = stateno = 410 && movecontact = 1
trigger4 = time >= 7
trigger5 = stateno = 210 && movecontact = 1
trigger6 = stateno = 240 && movecontact = 1
trigger7 = stateno = 200 && time > 3

;---------------------------------------------------------------------------
;Crouching Strong Kick
[State -1, Crouching Strong Kick]
type = ChangeState
value = 440
triggerall = var(21) != 1
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 400 && movecontact = 1
trigger3 = stateno = 440 && movecontact = 1
trigger4 = stateno = 410 && hitcount >= 2 ;&& movecontact = 1 && time > 8
trigger5 = stateno = 410 && movecontact = 1
trigger5 = time >= 7

;---------------------------------------------------------------------------
;Jump Meduim Weapon
[State -1, Jump Meduim Weapon]
type = ChangeState
value = 610
triggerall = var(21) != 1
triggerall = command = "y" ;"x" || command = "y"
triggerall = command = "holdup"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump Light Weapon
[State -1, Jump Light Weapon]
type = ChangeState
value = 600
triggerall = var(21) != 1
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 || stateno = 640 ;jump_x or jump_a
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump Strong Weapon
[State -1, Jump Strong Weapon]
type = ChangeState
value = 620
triggerall = var(21) != 1
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 || stateno = 640 ;jump_x or jump_a
trigger2 = movecontact
;trigger3 = stateno = 1350 ;Air blocking

;---------------------------------------------------------------------------
;Jump Meduim Kick
[State -1, Jump Meduim Kick]
type = ChangeState
value = 640
triggerall = var(21) != 1
triggerall = command = "a" || command = "b"
triggerall = command = "holddown"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 && movecontact = 1
trigger3 = stateno = 630 && movecontact = 1

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = var(21) != 1
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 || stateno = 640 ;jump_x or jump_a
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump Strong Kick
[State -1, Jump Strong Kick]
type = ChangeState
value = 650
triggerall = var(21) != 1
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 || stateno = 640 ;jump_x or jump_a
trigger2 = movecontact
